==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/KafkaMirrorMakerFluent.java <==
package io.strimzi.api.kafka.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.strimzi.api.kafka.model.status.KafkaMirrorMakerStatus;
import java.lang.StringBuilder;
import io.strimzi.api.kafka.model.status.KafkaMirrorMakerStatusBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.strimzi.api.kafka.model.status.KafkaMirrorMakerStatusFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaMirrorMakerFluent<A extends KafkaMirrorMakerFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public KafkaMirrorMakerFluent.MetadataNested<A> withNewMetadata();
    public KafkaMirrorMakerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public KafkaMirrorMakerFluent.MetadataNested<A> editMetadata();
    public KafkaMirrorMakerFluent.MetadataNested<A> editOrNewMetadata();
    public KafkaMirrorMakerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public KafkaMirrorMakerSpec getSpec();
    public KafkaMirrorMakerSpec buildSpec();
    public A withSpec(KafkaMirrorMakerSpec spec);
    public Boolean hasSpec();
    public KafkaMirrorMakerFluent.SpecNested<A> withNewSpec();
    public KafkaMirrorMakerFluent.SpecNested<A> withNewSpecLike(KafkaMirrorMakerSpec item);
    public KafkaMirrorMakerFluent.SpecNested<A> editSpec();
    public KafkaMirrorMakerFluent.SpecNested<A> editOrNewSpec();
    public KafkaMirrorMakerFluent.SpecNested<A> editOrNewSpecLike(KafkaMirrorMakerSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public KafkaMirrorMakerStatus getStatus();
    public KafkaMirrorMakerStatus buildStatus();
    public A withStatus(KafkaMirrorMakerStatus status);
    public Boolean hasStatus();
    public KafkaMirrorMakerFluent.StatusNested<A> withNewStatus();
    public KafkaMirrorMakerFluent.StatusNested<A> withNewStatusLike(KafkaMirrorMakerStatus item);
    public KafkaMirrorMakerFluent.StatusNested<A> editStatus();
    public KafkaMirrorMakerFluent.StatusNested<A> editOrNewStatus();
    public KafkaMirrorMakerFluent.StatusNested<A> editOrNewStatusLike(KafkaMirrorMakerStatus item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<KafkaMirrorMakerFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaMirrorMakerSpecFluent<KafkaMirrorMakerFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaMirrorMakerStatusFluent<KafkaMirrorMakerFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> api-0.23.0-sources.jar: io/strimzi/api/kafka/model/KafkaMirrorMakerFluent.java <==
package io.strimzi.api.kafka.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.strimzi.api.kafka.model.status.KafkaMirrorMakerStatus;
import java.lang.StringBuilder;
import io.strimzi.api.kafka.model.status.KafkaMirrorMakerStatusBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.strimzi.api.kafka.model.status.KafkaMirrorMakerStatusFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaMirrorMakerFluent<A extends KafkaMirrorMakerFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public KafkaMirrorMakerFluent.MetadataNested<A> withNewMetadata();
    public KafkaMirrorMakerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public KafkaMirrorMakerFluent.MetadataNested<A> editMetadata();
    public KafkaMirrorMakerFluent.MetadataNested<A> editOrNewMetadata();
    public KafkaMirrorMakerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public KafkaMirrorMakerSpec getSpec();
    public KafkaMirrorMakerSpec buildSpec();
    public A withSpec(KafkaMirrorMakerSpec spec);
    public Boolean hasSpec();
    public KafkaMirrorMakerFluent.SpecNested<A> withNewSpec();
    public KafkaMirrorMakerFluent.SpecNested<A> withNewSpecLike(KafkaMirrorMakerSpec item);
    public KafkaMirrorMakerFluent.SpecNested<A> editSpec();
    public KafkaMirrorMakerFluent.SpecNested<A> editOrNewSpec();
    public KafkaMirrorMakerFluent.SpecNested<A> editOrNewSpecLike(KafkaMirrorMakerSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public KafkaMirrorMakerStatus getStatus();
    public KafkaMirrorMakerStatus buildStatus();
    public A withStatus(KafkaMirrorMakerStatus status);
    public Boolean hasStatus();
    public KafkaMirrorMakerFluent.StatusNested<A> withNewStatus();
    public KafkaMirrorMakerFluent.StatusNested<A> withNewStatusLike(KafkaMirrorMakerStatus item);
    public KafkaMirrorMakerFluent.StatusNested<A> editStatus();
    public KafkaMirrorMakerFluent.StatusNested<A> editOrNewStatus();
    public KafkaMirrorMakerFluent.StatusNested<A> editOrNewStatusLike(KafkaMirrorMakerStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<KafkaMirrorMakerFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaMirrorMakerSpecFluent<KafkaMirrorMakerFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaMirrorMakerStatusFluent<KafkaMirrorMakerFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
